pub struct IndexVec<I: Idx, T> { /* private fields */ }Expand description
A Vec that can only be indexed by a specific index type I.
Implementations
Sourceimpl<I: Idx, T> IndexVec<I, T>
impl<I: Idx, T> IndexVec<I, T>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create with pre-allocated capacity.
Sourcepub fn get_mut(&mut self, idx: I) -> Option<&mut T>
pub fn get_mut(&mut self, idx: I) -> Option<&mut T>
Get a mutable reference to the value at the given index.
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>
Returns a mutable iterator over the values.
Sourcepub fn iter_enumerated(&self) -> impl Iterator<Item = (I, &T)>
pub fn iter_enumerated(&self) -> impl Iterator<Item = (I, &T)>
Returns an iterator over (index, value) pairs.