pub struct UnusedSymbolResult {
pub unused_symbols: Vec<UnusedSymbol>,
pub would_become_unused: Vec<UnusedSymbol>,
}Expand description
Result of unused symbol analysis.
Fields
unused_symbols: Vec<UnusedSymbol>Symbols that are currently unused (zero references).
would_become_unused: Vec<UnusedSymbol>Symbols that would become unused if a deletion occurred.
Implementations
Sourceimpl UnusedSymbolResult
impl UnusedSymbolResult
Sourcepub fn has_unused(&self) -> bool
pub fn has_unused(&self) -> bool
Check if there are any unused symbols.
Sourcepub fn has_potential_unused(&self) -> bool
pub fn has_potential_unused(&self) -> bool
Check if there are symbols that would become unused.
Sourcepub fn issue_count(&self) -> usize
pub fn issue_count(&self) -> usize
Get total count of issues.