pub struct FileId(/* private fields */);Expand description
Internal file identifier for fast processing.
Properties
- O(1) comparison and hashing
- Generation counter for dangling detection
- 8 bytes fixed size
Important: Only obtain through FileRegistry
FileId must always be obtained through FileRegistry::register() or
FileRegistry::lookup(). Direct creation is prohibited.
ⓘ
// Correct usage
let id = file_registry.register(path, crate_name);
let id = file_registry.lookup(&path)?;
// Prohibited: Direct creation
// let id = FileId::default(); // Compiles but prohibitedTrait Implementations
Sourceimpl<'de> Deserialize<'de> for FileId
impl<'de> Deserialize<'de> for FileId
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Key for FileId
impl Key for FileId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for FileId
impl Ord for FileId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for FileId
impl PartialOrd for FileId
impl Copy for FileId
impl Eq for FileId
impl StructuralPartialEq for FileId