UsageContext

Enum UsageContext 

pub enum UsageContext {
Show 15 variants FieldType, ParamType, ReturnType, LocalVar, WhereBound, ImplTarget, ImplTrait, UseStatement, Cast, Turbofish, VariantField, ConstType, MatchScrutinee, ConstructorCall, StructLiteral,
}
Context in which a type is used.

Variants



FieldType

Struct field type.



ParamType

Function parameter type.



ReturnType

Return type.



LocalVar

Local variable type annotation.



WhereBound

Where clause or trait bound.



ImplTarget

Impl target (impl Foo).



ImplTrait

Impl trait (impl Trait for Foo).



UseStatement

Use statement.



Cast

Type cast (as Type).



Turbofish

Turbofish (::<Type>).



VariantField

Enum variant field.



ConstType

Const/static type.



MatchScrutinee

Match expression scrutinee (the value being matched). Used to track where enums are matched for cascade analysis.



ConstructorCall

Associated function call: Foo::new(), Foo::default(), etc. Tracks the type referenced by the path prefix of the call.



StructLiteral

Struct literal: Foo { field: value }. Tracks the type being instantiated.