IndexVec - Type-safe indexed vector (rustc-style)
Provides a Vec wrapper that only accepts strongly-typed indices, preventing accidental index confusion between different ID types.
Structs
- Index
Vec - A Vec that can only be indexed by a specific index type
I.
Traits
- Idx
- Trait for index types that can be used with IndexVec.