pub struct BorrowTrackerV2 { /* private fields */ }Expand description
Tracks active borrows for a set of variables (V2 - uses VarId).
Integrates with DataFlowGraphV2 for borrow conflict detection.
Implementations
Sourceimpl BorrowTrackerV2
impl BorrowTrackerV2
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create with pre-allocated capacity.
Sourcepub fn add_borrow(
&mut self,
source: VarId,
borrower: VarId,
kind: BorrowKind,
line: u32,
) -> Vec<BorrowConflict>
pub fn add_borrow( &mut self, source: VarId, borrower: VarId, kind: BorrowKind, line: u32, ) -> Vec<BorrowConflict>
Add a borrow.
Returns any conflicts with existing borrows.
Sourcepub fn end_borrow(&mut self, borrower: VarId, line: u32)
pub fn end_borrow(&mut self, borrower: VarId, line: u32)
End a borrow.
Sourcepub fn conflicts(
&self,
source: VarId,
kind: BorrowKind,
at_line: u32,
) -> Vec<BorrowConflict>
pub fn conflicts( &self, source: VarId, kind: BorrowKind, at_line: u32, ) -> Vec<BorrowConflict>
Query conflicts with a potential new borrow.
Sourcepub fn active_borrows_at(
&self,
source: VarId,
line: u32,
) -> Vec<&ActiveBorrowV2>
pub fn active_borrows_at( &self, source: VarId, line: u32, ) -> Vec<&ActiveBorrowV2>
Get all active borrows of a variable at a given line.
Sourcepub fn active_borrows(&self, source: VarId) -> &[ActiveBorrowV2]
pub fn active_borrows(&self, source: VarId) -> &[ActiveBorrowV2]
Get all active borrows of a variable (regardless of line).
Sourcepub fn has_active_borrows(&self, source: VarId, at_line: u32) -> bool
pub fn has_active_borrows(&self, source: VarId, at_line: u32) -> bool
Check if any borrows are currently active for a variable.
Sourcepub fn has_active_mut_borrow(&self, source: VarId, at_line: u32) -> bool
pub fn has_active_mut_borrow(&self, source: VarId, at_line: u32) -> bool
Check if a mutable borrow is active for a variable.
Sourcepub fn tracked_var_count(&self) -> usize
pub fn tracked_var_count(&self) -> usize
Get the number of tracked variables.
Sourcepub fn total_borrow_count(&self) -> usize
pub fn total_borrow_count(&self) -> usize
Get the total number of borrows (active and ended).