pub struct StdImplCache { /* private fields */ }Expand description
Cache of known trait implementations for standard library types.
This is a static cache that knows which primitives and std types implement common traits like Clone, Default, Debug, etc.
Implementations
Sourceimpl StdImplCache
impl StdImplCache
Sourcepub fn has_impl(&self, type_name: &str, trait_name: &str) -> bool
pub fn has_impl(&self, type_name: &str, trait_name: &str) -> bool
Check if a type implements a trait.
Sourcepub fn is_primitive(&self, type_name: &str) -> bool
pub fn is_primitive(&self, type_name: &str) -> bool
Check if a type is a known primitive.
Sourcepub fn is_std_container(&self, type_name: &str) -> bool
pub fn is_std_container(&self, type_name: &str) -> bool
Check if a type is a known std container.
Sourcepub fn traits_for(&self, type_name: &str) -> Vec<&'static str>
pub fn traits_for(&self, type_name: &str) -> Vec<&'static str>
Get all traits a type is known to implement.